@@ -36,10 +36,8 @@ class CfnAssessmentTarget(
 ):
     """A CloudFormation ``AWS::Inspector::AssessmentTarget``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Inspector::AssessmentTarget
+    :cloudformationResource: AWS::Inspector::AssessmentTarget
     """
 
     def __init__(
@@ -66,11 +64,10 @@ class CfnAssessmentTarget(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -95,8 +92,7 @@ class CfnAssessmentTarget(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -110,7 +106,6 @@ class CfnAssessmentTarget(
     def assessment_target_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-assessmenttargetname
         """
         return jsii.get(self, "assessmentTargetName")
@@ -124,7 +119,6 @@ class CfnAssessmentTarget(
     def resource_group_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-resourcegrouparn
         """
         return jsii.get(self, "resourceGroupArn")
@@ -154,7 +148,6 @@ class CfnAssessmentTargetProps:
         :param assessment_target_name: ``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
         :param resource_group_arn: ``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -167,7 +160,6 @@ class CfnAssessmentTargetProps:
     def assessment_target_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-assessmenttargetname
         """
         result = self._values.get("assessment_target_name")
@@ -177,7 +169,6 @@ class CfnAssessmentTargetProps:
     def resource_group_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-resourcegrouparn
         """
         result = self._values.get("resource_group_arn")
@@ -203,10 +194,8 @@ class CfnAssessmentTemplate(
 ):
     """A CloudFormation ``AWS::Inspector::AssessmentTemplate``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Inspector::AssessmentTemplate
+    :cloudformationResource: AWS::Inspector::AssessmentTemplate
     """
 
     def __init__(
@@ -242,11 +231,10 @@ class CfnAssessmentTemplate(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -271,8 +259,7 @@ class CfnAssessmentTemplate(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -286,7 +273,6 @@ class CfnAssessmentTemplate(
     def assessment_target_arn(self) -> builtins.str:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttargetarn
         """
         return jsii.get(self, "assessmentTargetArn")
@@ -300,7 +286,6 @@ class CfnAssessmentTemplate(
     def duration_in_seconds(self) -> jsii.Number:
         """``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-durationinseconds
         """
         return jsii.get(self, "durationInSeconds")
@@ -314,7 +299,6 @@ class CfnAssessmentTemplate(
     def rules_package_arns(self) -> typing.List[builtins.str]:
         """``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-rulespackagearns
         """
         return jsii.get(self, "rulesPackageArns")
@@ -328,7 +312,6 @@ class CfnAssessmentTemplate(
     def assessment_template_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
         """
         return jsii.get(self, "assessmentTemplateName")
@@ -344,7 +327,6 @@ class CfnAssessmentTemplate(
     ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-userattributesforfindings
         """
         return jsii.get(self, "userAttributesForFindings")
@@ -386,7 +368,6 @@ class CfnAssessmentTemplateProps:
         :param assessment_template_name: ``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
         :param user_attributes_for_findings: ``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -403,7 +384,6 @@ class CfnAssessmentTemplateProps:
     def assessment_target_arn(self) -> builtins.str:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttargetarn
         """
         result = self._values.get("assessment_target_arn")
@@ -414,7 +394,6 @@ class CfnAssessmentTemplateProps:
     def duration_in_seconds(self) -> jsii.Number:
         """``AWS::Inspector::AssessmentTemplate.DurationInSeconds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-durationinseconds
         """
         result = self._values.get("duration_in_seconds")
@@ -425,7 +404,6 @@ class CfnAssessmentTemplateProps:
     def rules_package_arns(self) -> typing.List[builtins.str]:
         """``AWS::Inspector::AssessmentTemplate.RulesPackageArns``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-rulespackagearns
         """
         result = self._values.get("rules_package_arns")
@@ -436,7 +414,6 @@ class CfnAssessmentTemplateProps:
     def assessment_template_name(self) -> typing.Optional[builtins.str]:
         """``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
         """
         result = self._values.get("assessment_template_name")
@@ -448,7 +425,6 @@ class CfnAssessmentTemplateProps:
     ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-userattributesforfindings
         """
         result = self._values.get("user_attributes_for_findings")
@@ -474,10 +450,8 @@ class CfnResourceGroup(
 ):
     """A CloudFormation ``AWS::Inspector::ResourceGroup``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::Inspector::ResourceGroup
+    :cloudformationResource: AWS::Inspector::ResourceGroup
     """
 
     def __init__(
@@ -499,11 +473,10 @@ class CfnResourceGroup(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -528,8 +501,7 @@ class CfnResourceGroup(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -545,7 +517,6 @@ class CfnResourceGroup(
     ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]:
         """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html#cfn-inspector-resourcegroup-resourcegrouptags
         """
         return jsii.get(self, "resourceGroupTags")
@@ -573,7 +544,6 @@ class CfnResourceGroupProps:
 
         :param resource_group_tags: ``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -586,7 +556,6 @@ class CfnResourceGroupProps:
     ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]:
         """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html#cfn-inspector-resourcegroup-resourcegrouptags
         """
         result = self._values.get("resource_group_tags")
